"use client";

import { useEffect, useState } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useStudents } from "@/lib/hooks/useStudents";
import { useTeachers } from "@/lib/hooks/useTeachers";
import { useClasses } from "@/lib/hooks/useClasses";
import { useAttendance } from "@/lib/hooks/useAttendance";
import { useActivity } from "@/lib/hooks/useActivity";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { StatCard } from "@/components/dashboard/StatCard";
import { ChartContainer } from "@/components/dashboard/ChartContainer";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Users, UserCog, BookOpen, BarChart3 } from "lucide-react";
import { format, subMonths } from "date-fns";

export default function DashboardPage() {
  const router = useRouter();
  const { user, loading: authLoading } = useAuth();
  const { students } = useStudents();
  const { teachers } = useTeachers();
  const { classes } = useClasses();
  const { getWeeklyAttendance } = useAttendance();
  const { activities, loading: activitiesLoading } = useActivity();
  const [classDistribution, setClassDistribution] = useState<any[]>([]);
  const [weeklyAttendance, setWeeklyAttendance] = useState<any[]>([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    // Redirect if not authenticated
    if (!authLoading && !user) {
      router.push("/auth");
    }
  }, [user, authLoading, router]);

  useEffect(() => {
    const fetchWeeklyAttendance = async () => {
      if (classes.length > 0) {
        try {
          // Get dates for the current week
          const today = new Date();
          const startOfWeek = new Date(today);
          startOfWeek.setDate(today.getDate() - today.getDay());
          const endOfWeek = new Date(today);
          endOfWeek.setDate(startOfWeek.getDate() + 6);

          const startDate = format(startOfWeek, "yyyy-MM-dd");
          const endDate = format(endOfWeek, "yyyy-MM-dd");

          // Get attendance data for the first class
          const weeklyData = await getWeeklyAttendance(classes[0].id, startDate, endDate);
          
          // Transform data for chart
          const chartData = weeklyData.map(day => ({
            name: day.day.substring(0, 3), // Abbreviate day names
            present: day.present,
            absent: day.absent,
            late: day.late
          }));
          
          setWeeklyAttendance(chartData);
        } catch (error) {
          console.error("Error fetching weekly attendance:", error);
        }
      }
      setIsLoading(false);
    };

    fetchWeeklyAttendance();
  }, [classes, getWeeklyAttendance]);

    // Calculate class distribution
    useEffect(() => {
      const classStats = classes.map(cls => {
        const studentsInClass = students.filter(s => 
          s.classIds?.includes(cls.id)
        ).length;
        return {
          name: cls.level ? `${cls.name} (${cls.level})` : cls.name, // Include level here
          value: studentsInClass,
          originalName: cls.name, // Keep original name if needed for other purposes
        };
      });

  setClassDistribution(classStats);
}, [students, classes]);

  // Calculate student status distribution
  const studentStatusData = [
    { name: "Active", value: students.filter(s => s.status === "active").length },
    { name: "Inactive", value: students.filter(s => s.status === "inactive").length },
    { name: "Archived", value: students.filter(s => s.status === "archived").length },
  ];

  // Calculate gender distribution
  const genderDistribution = [
    { name: "Male", value: students.filter(s => s.gender === "male").length },
    { name: "Female", value: students.filter(s => s.gender === "female").length },
  ];

  // Calculate monthly attendance trend (last 6 months)
  const calculateMonthlyAttendance = () => {
    const months = [];
    for (let i = 5; i >= 0; i--) {
      const date = subMonths(new Date(), i);
      const monthName = format(date, "MMM");
      const activeStudents = students.filter(s => s.status === "active").length;
      months.push({
        name: monthName,
        value: activeStudents
      });
    }
    return months;
  };

  const monthlyAttendanceData = calculateMonthlyAttendance();

  if (authLoading || isLoading || activitiesLoading) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Dashboard</h1>
          <p className="text-muted-foreground">
            Overview of your school management system
          </p>
        </div>

        {/* Stats Cards */}
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
          <StatCard
            title="Total Students"
            value={students.length}
            icon={<Users className="h-5 w-5" />}
            description="Currently enrolled students"
          />
          <StatCard
            title="Total Teachers"
            value={teachers.length}
            icon={<UserCog className="h-5 w-5" />}
            description="Active teaching staff"
          />
          <StatCard
            title="Total Classes"
            value={classes.length}
            icon={<BookOpen className="h-5 w-5" />}
            description="Active classes"
          />
        </div>

        {/* Charts */}
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          {/* Students Per Class Chart */}
          <Card>
            <CardHeader>
              <CardTitle>Students per Class</CardTitle>
              <p className="text-sm text-muted-foreground">
                Distribution of students across classes
              </p>
            </CardHeader>
            <CardContent>
              <ChartContainer
                title=""
                type="bar"
                data={classDistribution}
              />
            </CardContent>
          </Card>

          {/* Gender Distribution */}
          <ChartContainer
            title="Gender Distribution"
            description="Distribution of students by gender"
            type="pie"
            data={genderDistribution}
          />
        </div>

        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          {/* Student Status Distribution */}
          <ChartContainer
            title="Student Status Distribution"
            description="Current status of all students"
            type="pie"
            data={studentStatusData}
          />

          {/* Monthly Attendance Trend */}
          <ChartContainer
            title="Monthly Student Count"
            description="Active students over the past 6 months"
            type="line"
            data={monthlyAttendanceData}
          />
        </div>

        {/* Recent Activity */}
        <Card>
          <CardHeader>
            <CardTitle className="flex items-center">
              <BarChart3 className="mr-2 h-5 w-5" />
              Recent Activity
            </CardTitle>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {activities.map((activity) => (
                <div key={activity.id} className="flex justify-between items-center">
                  <div className="space-y-1">
                    <p className="text-sm font-medium">
                      {activity.title}
                    </p>
                    <p className="text-xs text-muted-foreground">
                      {activity.subject}
                      {activity.details && (
                        <span className="text-xs text-muted-foreground ml-1">
                          • {activity.details}
                        </span>
                      )}
                    </p>
                  </div>
                  <p className="text-xs text-muted-foreground">
                    {new Date(activity.date).toLocaleDateString('en-GB', {
                      day: '2-digit',
                      month: 'short',
                      year: 'numeric',
                      hour: '2-digit',
                      minute: '2-digit'
                    })}
                  </p>
                </div>
              ))}
              {activities.length === 0 && (
                <p className="text-center text-muted-foreground">No recent activity</p>
              )}
            </div>
          </CardContent>
        </Card>
      </div>
    </DashboardLayout>
  );
}